﻿using Syncfusion.SfNumericTextBox.XForms;
using Syncfusion.XForms.ComboBox;
using Syncfusion.XForms.DataForm;
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace dataform
{
    public class StartPage : ContentPage
    {
        SfDataForm activationForm;
        public StartPage()
        {
            activationForm = new SfDataForm()
            {
                HorizontalOptions = LayoutOptions.FillAndExpand,
                VerticalOptions = LayoutOptions.FillAndExpand
            };
            activationForm.LayoutManager = new DataformItem(this.activationForm);
            activationForm.LabelWidth = 1;
            activationForm.EditorWidth = 2;
            activationForm.CommitMode = CommitMode.PropertyChanged;
            activationForm.RegisterEditor("DisplayGender", "DropDown");
            activationForm.AutoGeneratingDataFormItem += DataForm_AutoGeneratingDataFormItem;
        }

        protected override void OnAppearing()
        {
            base.OnAppearing();
            activationForm.DataObject = new FormDto();

            var layout = new StackLayout
            {
                HorizontalOptions = LayoutOptions.FillAndExpand,
                VerticalOptions = LayoutOptions.FillAndExpand,
                Margin = new Thickness(10, 20, 10, 20),
                Spacing = 5,
            };
           

            var header = new Label
            {
                Text = "To get started just complete the form below. Please note that a valid email address will be your username.",
                HorizontalTextAlignment = TextAlignment.Center,
                TextColor = Color.FromHex(HJHexColors.HJDarkText)
            };

            var termsGrid = new Grid()
            {
                RowDefinitions =
                {
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                },
                ColumnDefinitions =
                {
                    new ColumnDefinition {Width = new GridLength(.1, GridUnitType.Star) },
                    new ColumnDefinition {Width = new GridLength(.9, GridUnitType.Star) },
                },
            };
            var termsAgreed = new Label
            {
                Text = "\u2713",
                FontSize = DeviceFont.FontSize("xxlarge"),
                Opacity = .5,
                VerticalOptions = LayoutOptions.Start,
                Margin = new Thickness(0, 10, 0, 10),
            };
            termsGrid.Children.Add(termsAgreed, 0, 0);           
            termsGrid.Children.Add(new TermsLabel(), 1, 0);

            var activateBtn = new Button
            {
                Text = "Create Account",
                BackgroundColor = Color.FromHex(HJHexColors.HJCorpOrange),
                TextColor = Color.FromHex(HJHexColors.HJWhite),
                Margin = new Thickness(10, 10, 10, 10),
            };

            var supportLabel = new Label
            {
                Text = "Having difficulty activating your account? Contact HealthJibe support at support@healthjibe.com",
                Margin = new Thickness(10),
                FontSize = DeviceFont.FontSize("large"),
            };

            layout.Children.Add(header);
            layout.Children.Add(activationForm);
            layout.Children.Add(termsGrid);
            layout.Children.Add(activateBtn);
            layout.Children.Add(supportLabel);

            this.SetBinding(IsBusyProperty, "IsBusy");
            Content = new ScrollView() { Content = layout };
        }

        private void DataForm_AutoGeneratingDataFormItem(object sender, AutoGeneratingDataFormItemEventArgs e)
        {
            if (e.DataFormItem != null && e.DataFormItem.Name == "DisplayGender")
            {
                var list = new List<string>();
                list.Add("Male");
                list.Add("Female");
                (e.DataFormItem as DataFormDropDownItem).ItemsSource = list;
            }
            if (e.DataFormItem.Name == "Header")
                e.DataFormItem.IsReadOnly = true;
        }

        private class TermsLabel : ContentView
        {
            public TermsLabel()
            {
                var text = new FormattedString();
                text.Spans.Add(new Span { Text = "I have read and agree to the ", ForegroundColor = Color.FromHex(HJHexColors.HJBlack) });
                text.Spans.Add(new Span { Text = "Terms of Use", ForegroundColor = Color.FromHex(HJHexColors.HJCorpOrange) });
                var label = new Label()
                {
                    FormattedText = text,
                    VerticalOptions = LayoutOptions.Center,
                    FontSize = DeviceFont.FontSize("large"),
                };
                
                Content = label;
            }
        }

        public class DataformItem : DataFormLayoutManager
        {
            public DataformItem(SfDataForm dataForm) : base(dataForm)
            {

            }

            protected override View GenerateViewForLabel(DataFormItem dataFormItem)
            {
                var view = base.GenerateViewForLabel(dataFormItem);
                (view as Label).FontSize = DeviceFont.FontSize("small");
                (view as Label).TextColor = Color.FromHex(HJHexColors.HJDarkText);
                (view as Label).FontFamily = DeviceFont.FontType();
                return view;

            }

            protected override View GenerateViewForGroupHeader(DataFormGroupItem dataFormGroupItem)
            {
                var view = base.GenerateViewForGroupHeader(dataFormGroupItem);
                (view as Label).FontSize = DeviceFont.FontSize("standard");
                (view as Label).TextColor = Color.FromHex(HJHexColors.HJDarkText);
                (view as Label).FontFamily = DeviceFont.FontType();
                return view;
            }

            protected override void OnEditorCreated(DataFormItem dataFormItem, View editor)
            {
                if (editor is Entry)
                {
                    (editor as Entry).TextColor = Color.FromHex(HJHexColors.HJDarkText);
                    (editor as Entry).FontSize = DeviceFont.FontSize("small");
                    (editor as Entry).FontFamily = DeviceFont.FontType();
                }
                else if (editor is SfNumericTextBox)
                {
                    (editor as SfNumericTextBox).TextColor = Color.FromHex(HJHexColors.HJDarkText);
                    (editor as SfNumericTextBox).FontSize = DeviceFont.FontSize("small");
                    (editor as SfNumericTextBox).FontFamily = DeviceFont.FontType();
                }
                else if (editor is DatePicker)
                {
                    (editor as DatePicker).TextColor = Color.FromHex(HJHexColors.HJDarkText);
                    (editor as DatePicker).Format = "MMM dd yyyy";
                    //(editor as DatePicker).FontFamily = DeviceFont.FontType();
                    //(editor as DatePicker).FontSize = DeviceFont.FontSize("standard");
                }
                else if (editor is SfComboBox)
                {
                    (editor as SfComboBox).TextColor = Color.FromHex(HJHexColors.HJDarkText);
                    (editor as SfComboBox).FontFamily = DeviceFont.FontType();
                    (editor as SfComboBox).TextSize = DeviceFont.FontSize("small");
                }
            }
        }


        public class DeviceFont
        {

            public static string FontType()
            {
                switch (Device.RuntimePlatform)
                {
                    case Device.iOS:
                        return "HelveticaNeue";
                    case Device.Android:
                        return "Droid Sans";
                    default:
                        return "Comic Sans MS";
                }
            }

            public static int FontSize(string size = "standard")
            {
                switch (size)
                {
                    case "xsmall":
                        switch (Device.RuntimePlatform)
                        {
                            case Device.iOS:
                                return HJFontSizes.HJiOSXSmallFont;
                            case Device.Android:
                                return HJFontSizes.HJdroidXSmallFont;
                            default:
                                return 10;
                        }
                    case "small":
                        switch (Device.RuntimePlatform)
                        {
                            case Device.iOS:
                                return HJFontSizes.HJiOSSmallFont;
                            case Device.Android:
                                return HJFontSizes.HJdroidSmallFont;
                            default:
                                return 10;
                        }
                    case "large":
                        switch (Device.RuntimePlatform)
                        {
                            case Device.iOS:
                                return HJFontSizes.HJiOSLargeFont;
                            case Device.Android:
                                return HJFontSizes.HJdroidLargeFont;
                            default:
                                return 10;
                        }
                    case "xlarge":
                        switch (Device.RuntimePlatform)
                        {
                            case Device.iOS:
                                return HJFontSizes.HJiOSXLargeFont;
                            case Device.Android:
                                return HJFontSizes.HJdroidXLargeFont;
                            default:
                                return 10;
                        }
                    case "xxlarge":
                        switch (Device.RuntimePlatform)
                        {
                            case Device.iOS:
                                return HJFontSizes.HJiOSXXLargeFont;
                            case Device.Android:
                                return HJFontSizes.HJdroidXXLargeFont;
                            default:
                                return 10;
                        }
                    default:
                        switch (Device.RuntimePlatform)
                        {
                            case Device.iOS:
                                return HJFontSizes.HJiOSStandardFont;
                            case Device.Android:
                                return HJFontSizes.HJdroidStandardFont;
                            default:
                                return 10;
                        }
                }
            }

        }
        public class HJFontSizes
        {
            public const int HJiOSStandardFont = 16;
            public const int HJiOSLargeFont = 18;
            public const int HJiOSXLargeFont = 24;
            public const int HJiOSXXLargeFont = 36;
            public const int HJiOSSmallFont = 14;
            public const int HJiOSXSmallFont = 12;

            public const int HJdroidStandardFont = 14;
            public const int HJdroidLargeFont = 16;
            public const int HJdroidXLargeFont = 22;
            public const int HJdroidXXLargeFont = 34;
            public const int HJdroidSmallFont = 12;
            public const int HJdroidXSmallFont = 10;
        }
        public static class HJHexColors
        {
            public const string HJEngagement = "83C2EB";
            public const string HJClaims = "8CA40B";
            public const string HJFeed = "DA3548";
            public const string HJMbs = "F3731c";
            public const string HJCarePlan = "FBCB06";
            public const string HJGray = "606060";
            public const string HJWhite = "FFFFFF";
            public const string HJBlack = "000000";
            public const string HJCorpOrange = "F3731C";
            public const string HJDarkBlue = "4889B7";
            public const string HJInfoYellow = "FBCC04";
            public const string HJConfirm = "94b435";
            public const string HJAlert = "fd4246";
            public const string HJSeparator = "CCCCCC";
            public const string HJTabUnselected = "A6A6A6";
            public const string HJLightYellow = "fde170";
            public const string HJDarkText = "555555";
            public const string HJPrimaryText = "333333";
            public const string HJLightGreen = "E3EEA9";
            public const string HJLightGray = "f9f9f9";
            public const string HJHeaderBackground = "edebf1";
            public const string HJChartSeriesBlue = "83C2EB";
            public const string HJChartSeriesGreen = "8CA40B";
            public const string HJChartSeriesOrange = "F3731c";
            public const string HJChartSeriesRed = "DA3548";
        }
    }

}
